tiled.readers.tiff.TiffReader
=============================

.. currentmodule:: tiled.readers.tiff

.. autoclass:: TiffReader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TiffReader.__init__
      ~TiffReader.macrostructure
      ~TiffReader.microstructure
      ~TiffReader.read
      ~TiffReader.read_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TiffReader.metadata
      ~TiffReader.structure_family
   
   